@@ -1,6 +1,6 @@
 /*
  *  Bubbling Load Monitoring Applet
- *  Copyright (C) 1999-2004 Johan Walles - walles@mailblocks.com
+ *  Copyright (C) 1999-2004 Johan Walles - johan.walles@gmail.com
  *  http://www.nongnu.org/bubblemon/
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -119,13 +119,13 @@ static void usage2string(/*@out@*/ char *string,
 
   if (divisor_char == '\0')
     {
-      sprintf(string, "%llu/%llu bytes",
+      sprintf(string, _("%llu/%llu bytes"),
 	      used >> shiftme,
 	      max >> shiftme);
     }
   else
     {
-      sprintf(string, "%llu/%llu%cb",
+      sprintf(string, _("%llu/%llu%cb"),
 	      used >> shiftme,
 	      max >> shiftme,
 	      divisor_char);
